summaryrefslogtreecommitdiffstats
path: root/tdecore
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 19:10:38 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 19:10:38 -0600
commit99cc03399059853dd8699cae5752e8122cb715f1 (patch)
tree825da375ac05fc555e25b2e350504e211d85d2fb /tdecore
parentd5b3ae721dc072e0c70055313de9b5228b6688a8 (diff)
downloadtdelibs-99cc03399059853dd8699cae5752e8122cb715f1.tar.gz
tdelibs-99cc03399059853dd8699cae5752e8122cb715f1.zip
Rename KDEHOME and KDEDIR
Diffstat (limited to 'tdecore')
-rw-r--r--tdecore/DESIGN.kconfig4
-rw-r--r--tdecore/README.kiosk50
-rw-r--r--tdecore/kaudioplayer.h2
-rw-r--r--tdecore/kcrash.cpp2
-rw-r--r--tdecore/kdebugrc2
-rw-r--r--tdecore/knotifyclient.h2
-rw-r--r--tdecore/kstandarddirs.cpp22
-rw-r--r--tdecore/kstandarddirs.h20
-rw-r--r--tdecore/ksycoca.h2
-rw-r--r--tdecore/ktempdir.h2
-rw-r--r--tdecore/ktempfile.h2
11 files changed, 55 insertions, 55 deletions
diff --git a/tdecore/DESIGN.kconfig b/tdecore/DESIGN.kconfig
index e683566cb..4ced76726 100644
--- a/tdecore/DESIGN.kconfig
+++ b/tdecore/DESIGN.kconfig
@@ -52,7 +52,7 @@ void deleteEntry(key); // Remove entry
Note that there is a subtle difference between revertToDefault() and deleteEntry().
revertToDefault() will change the entry to the default value set by the system
-administrator (Via e.g. $KDEDIR/share/config) or, if no such default was set,
+administrator (Via e.g. $TDEDIR/share/config) or, if no such default was set,
non-existant.
deleteEntry() will make the entry non-existant.
@@ -123,7 +123,7 @@ mandatory if enums become an explicit type.
Instead of relying on the defaults that are hard-coded in the application,
-rely on default configuration files being installed in $KDEDIR. The technical
+rely on default configuration files being installed in $TDEDIR. The technical
changes required for this are very minimal, it is mostly a change in policy.
Type information can be provide by preceding every entry with a formalized
diff --git a/tdecore/README.kiosk b/tdecore/README.kiosk
index 257c5a446..351173231 100644
--- a/tdecore/README.kiosk
+++ b/tdecore/README.kiosk
@@ -24,17 +24,17 @@ for its applications. Resources range from icons, wallpapers, fonts to
sounds, menu-descriptions and configuration files.
In KDE1 there were two locations were resources could be located: The
-resources provided by the system were located under $KDEDIR and user-
+resources provided by the system were located under $TDEDIR and user-
specific resources were located under $HOME/.kde.
In KDE2 resource management has been largely abstracted by the introduction
of the KStandardDirs class and has become much more flexible. The user /
administrator can now specify a variable number of locations where resources
-can be found. A list of locations can either be specified via $KDEDIRS
+can be found. A list of locations can either be specified via $TDEDIRS
(notice the extra 'S'), via /etc/kderc and even via the kdeglobals config
file. The location where user-specific resources can be found can be
-set with $KDEHOME (The default is $HOME/.kde). Changes made by the user
-are always written back to $KDEHOME.
+set with $TDEHOME (The default is $HOME/.kde). Changes made by the user
+are always written back to $TDEHOME.
Both KDE1 and KDE2 feature so called "cascading configuration files": There
can be multiple configuration files with the same name in the various
@@ -42,29 +42,29 @@ locations for (config) resources, when that is the case, the information of
all these configuration files is combined on a key by key basis. If the same
key (within a certain group) is defined in more than one place, the value
of the key for the config file that was read last will override any previously
-read values. Configuration files under $KDEHOME are always read last. This
+read values. Configuration files under $TDEHOME are always read last. This
ensures that after a configuration entry is written, the same value wil be
read back.
In KDE3 two important changes have been made:
* Default values are no longer written.
-When a configuration file in a location other than $KDEHOME defines a value
+When a configuration file in a location other than $TDEHOME defines a value
for a key and the application subsequently writes out a new configuration file
-to $KDEHOME, that configuration file will only contain an entry for the key
+to $TDEHOME, that configuration file will only contain an entry for the key
if its value differs from the value read from the other file.
This counters the problem that changing default configuration files under
-$KDEDIR would not take effect for users, since these users would most likely
-have their own copy of these settings under $KDEHOME. KDE3 will make sure
-not to copy these settings so changes made under $KDEDIR will affect all users
+$TDEDIR would not take effect for users, since these users would most likely
+have their own copy of these settings under $TDEHOME. KDE3 will make sure
+not to copy these settings so changes made under $TDEDIR will affect all users
that haven't explicitly changed the affected settings to something else.
* Configuration entries can be marked "immutable".
Starting with KDE3, configuration entries can be marked "immutable". When a
configuration entry is immutable it means that configuration files that are
read later will not be able to override its value. Immutable entries cannot
-be changed via KConfig and if the entry is present under $KDEHOME it will
+be changed via KConfig and if the entry is present under $TDEHOME it will
be ignored.
Entries can be marked immutable on 4 different levels:
@@ -383,8 +383,8 @@ shell_access
option (Alt-F2) can be used to run shell-commands and arbitrary
executables. Likewise, executables placed in the user's
Autostart folder will no longer be executed. Applications can
- still be autostarted by placing .desktop files in the $KDEHOME/Autostart
- or $KDEDIR/share/autostart directory.
+ still be autostarted by placing .desktop files in the $TDEHOME/Autostart
+ or $TDEDIR/share/autostart directory.
See also run_desktop_files.
custom_config
@@ -416,13 +416,13 @@ run_desktop_files
part of the default desktop, KDE menu, registered services and
autostarting services.
* The default desktop includes the files under
- $KDEDIR/share/kdesktop/Desktop but _NOT_ the files under
+ $TDEDIR/share/kdesktop/Desktop but _NOT_ the files under
$HOME/Desktop.
- * The KDE menu includes all files under $KDEDIR/share/applnk and
+ * The KDE menu includes all files under $TDEDIR/share/applnk and
$XDGDIR/applications
- * Registered services includes all files under $KDEDIR/share/services.
- * Autostarting services include all files under $KDEDIR/share/autostart
- but _NOT_ the files under $KDEHOME/Autostart
+ * Registered services includes all files under $TDEDIR/share/services.
+ * Autostarting services include all files under $TDEDIR/share/autostart
+ but _NOT_ the files under $TDEHOME/Autostart
You probably also want to activate the following resource
restictions:
@@ -432,7 +432,7 @@ run_desktop_files
"services" - To restrict registered services.
"autostart" - To restrict autostarting services.
Otherwise users can still execute .desktop files by placing them
- in e.g. $KDEHOME/share/kdesktop/Desktop
+ in e.g. $TDEHOME/share/kdesktop/Desktop
lineedit_text_completion
- defines whether input lines should have the potential to remember
@@ -553,14 +553,14 @@ Some remarks:
KDE3 Resource Restrictions
==========================
Most KDE applications make use of additional resource files that are typically
-located in directories under $KDEDIR/share. By default KDE allows users to
+located in directories under $TDEDIR/share. By default KDE allows users to
override any of these resources by placing files in the same location
-under $KDEHOME/share. For example, Konsole stores profiles under
-$KDEDIR/share/apps/konsole and users can add additional profiles by
-installing files in $KDEHOME/share/apps/konsole.
+under $TDEHOME/share. For example, Konsole stores profiles under
+$TDEDIR/share/apps/konsole and users can add additional profiles by
+installing files in $TDEHOME/share/apps/konsole.
KDE3 Resource Restrictions make it possible to restrict the lookup of files
-to directories outside of $KDEHOME only.
+to directories outside of $TDEHOME only.
The following resources are defined:
@@ -589,7 +589,7 @@ data_<appname> - covers the sub section for <appname> in the data resource.
To restrict resources the kdeglobals file should contain the
group "[KDE Resource Restrictions]", each resource can then be restricted by
adding "<resource>=false". E.g. to restrict the "wallpaper" resource to
-$KDEDIR/share/wallpapers one would add:
+$TDEDIR/share/wallpapers one would add:
[KDE Resource Restrictions][$i]
wallpaper=false
diff --git a/tdecore/kaudioplayer.h b/tdecore/kaudioplayer.h
index dae00c4c7..327713e6d 100644
--- a/tdecore/kaudioplayer.h
+++ b/tdecore/kaudioplayer.h
@@ -75,7 +75,7 @@ public:
* Static play function.
*
* @param filename Absolute path to the filename of the sound file to play.
- * if not absolute, goes off KDEDIR/share/sounds/ (preferred)
+ * if not absolute, goes off TDEDIR/share/sounds/ (preferred)
*/
static void play(const TQString &filename);
diff --git a/tdecore/kcrash.cpp b/tdecore/kcrash.cpp
index dbbd41338..ffefcf97c 100644
--- a/tdecore/kcrash.cpp
+++ b/tdecore/kcrash.cpp
@@ -434,7 +434,7 @@ static int openSocket()
#define MAX_SOCK_FILE 255
char sock_file[MAX_SOCK_FILE + 1];
const char *home_dir = getenv("HOME");
- const char *kde_home = getenv("KDEHOME");
+ const char *kde_home = getenv("TDEHOME");
char *display;
sock_file[0] = sock_file[MAX_SOCK_FILE] = 0;
diff --git a/tdecore/kdebugrc b/tdecore/kdebugrc
index 58b09ae7a..10032a633 100644
--- a/tdecore/kdebugrc
+++ b/tdecore/kdebugrc
@@ -2,7 +2,7 @@
# This allows to leave the kdDebug* calls in the code, but still have them
# disabled for most users.
#
-# This file will be installed as $KDEDIR/share/config/kdebugrc
+# This file will be installed as $TDEDIR/share/config/kdebugrc
#
# There are four levels of output: Info, Warn, Error and Fatal
# corresponding to kdDebug(), kdWarn(), kdError(), kdFatal()
diff --git a/tdecore/knotifyclient.h b/tdecore/knotifyclient.h
index eeb5868d2..1eeebbb0a 100644
--- a/tdecore/knotifyclient.h
+++ b/tdecore/knotifyclient.h
@@ -27,7 +27,7 @@ class KInstance;
* This namespace provides a method for issuing events to a KNotifyServer
* call KNotifyClient::event("eventname"); to issue it.
* On installation, there should be a file called
- * $KDEDIR/share/apps/appname/eventsrc which contains the events.
+ * $TDEDIR/share/apps/appname/eventsrc which contains the events.
*
* The file looks like this:
* \code
diff --git a/tdecore/kstandarddirs.h b/tdecore/kstandarddirs.h
index afa875895..6d695c175 100644
--- a/tdecore/kstandarddirs.h
+++ b/tdecore/kstandarddirs.h
@@ -105,17 +105,17 @@ class KStandardDirsPrivate;
*
* <b>KStandardDirs supports the following environment variables:</b>
*
- * @li KDEDIRS: This may set an additional number of directory prefixes to
+ * @li TDEDIRS: This may set an additional number of directory prefixes to
* search for resources. The directories should be separated
* by ':'. The directories are searched in the order they are
* specified.
- * @li KDEDIR: Used for backwards compatibility. As KDEDIRS but only a single
- * directory may be specified. If KDEDIRS is set KDEDIR is
+ * @li TDEDIR: Used for backwards compatibility. As TDEDIRS but only a single
+ * directory may be specified. If TDEDIRS is set TDEDIR is
* ignored.
- * @li KDEHOME: The directory where changes are saved to. This directory is
- * used to search for resources first. If KDEHOME is not
+ * @li TDEHOME: The directory where changes are saved to. This directory is
+ * used to search for resources first. If TDEHOME is not
* specified it defaults to "$HOME/.kde"
- * @li KDEROOTHOME: Like KDEHOME, but used for the root user.
+ * @li KDEROOTHOME: Like TDEHOME, but used for the root user.
* If KDEROOTHOME is not set it defaults to the .kde directory in the
* home directory of root, usually "/root/.kde".
* Note that the setting of $HOME is ignored in this case.
@@ -139,7 +139,7 @@ public:
* Adds another search dir to front of the @p fsstnd list.
*
* @li When compiling tdelibs, the prefix is added to this.
- * @li KDEDIRS or KDEDIR is taking into account
+ * @li TDEDIRS or TDEDIR is taking into account
* @li Additional dirs may be loaded from kdeglobals.
*
* @param dir The directory to append relative paths to.
@@ -213,7 +213,7 @@ public:
* for resources. So is a way to get the path to libtdecore.la
* to findResource("lib", "libtdecore.la"). KStandardDirs will
* then look into the subdir lib of all elements of all prefixes
- * ($KDEDIRS) for a file libtdecore.la and return the path to
+ * ($TDEDIRS) for a file libtdecore.la and return the path to
* the first one it finds (e.g. /opt/kde/lib/libtdecore.la)
*
* @param type The type of the wanted resource
@@ -232,7 +232,7 @@ public:
*
* E.g. by restricting the "wallpaper" resource, only system-wide
* installed wallpapers will be found by this class. Wallpapers
- * installed under the $KDEHOME directory will be ignored.
+ * installed under the $TDEHOME directory will be ignored.
*
* @param type The type of the resource to check
* @param relPath A relative path in the resource.
@@ -631,7 +631,7 @@ public:
// Like their public counter parts but with an extra priority argument
// If priority is true, the directory is added directly after
- // $KDEHOME/$XDG_DATA_HOME/$XDG_CONFIG_HOME
+ // $TDEHOME/$XDG_DATA_HOME/$XDG_CONFIG_HOME
void addPrefix( const TQString& dir, bool priority );
void addXdgConfigPrefix( const TQString& dir, bool priority );
void addXdgDataPrefix( const TQString& dir, bool priority );
diff --git a/tdecore/ksycoca.h b/tdecore/ksycoca.h
index 19ab6674b..adf9d2aa7 100644
--- a/tdecore/ksycoca.h
+++ b/tdecore/ksycoca.h
@@ -99,7 +99,7 @@ public:
* @internal - returns update signature of database
*
* Signature that keeps track of changes to
- * $KDEDIR/share/services/update_ksycoca
+ * $TDEDIR/share/services/update_ksycoca
*
* Touching this file causes the database to be recreated
* from scratch.
diff --git a/tdecore/ktempdir.h b/tdecore/ktempdir.h
index 414eabf52..f5b2f8026 100644
--- a/tdecore/ktempdir.h
+++ b/tdecore/ktempdir.h
@@ -57,7 +57,7 @@ public:
* Creates a temporary directory with the name:
* \p \<directoryPrefix\>\<six letters\>
*
- * The default \p directoryPrefix is "$KDEHOME/tmp-$HOST/appname"
+ * The default \p directoryPrefix is "$TDEHOME/tmp-$HOST/appname"
* @param directoryPrefix the prefix of the file name, or
* TQString::null for the default value
* @param mode the file permissions,
diff --git a/tdecore/ktempfile.h b/tdecore/ktempfile.h
index 1c9378ba8..38cd8b5aa 100644
--- a/tdecore/ktempfile.h
+++ b/tdecore/ktempfile.h
@@ -60,7 +60,7 @@ public:
* Creates a temporary file with the name:
* \<filePrefix>\<six letters>\<fileExtension>
*
- * The default @p filePrefix is "$KDEHOME/tmp-$HOST/appname/"
+ * The default @p filePrefix is "$TDEHOME/tmp-$HOST/appname/"
* The default @p fileExtension is ".tmp"
* @param filePrefix the prefix of the file name, or TQString::null
* for the default value
diff --git a/tdecore/kstandarddirs.cpp b/tdecore/kstandarddirs.cpp
index 87a509e13..a0b25dcbb 100644
--- a/tdecore/kstandarddirs.cpp
+++ b/tdecore/kstandarddirs.cpp
@@ -167,7 +167,7 @@ static void priorityAdd(TQStringList &prefixes, const TQString& dir, bool priori
{
if (priority && !prefixes.isEmpty())
{
// Add in front but behind $KDEHOME
TQStringList::iterator it = prefixes.begin();
it++;
prefixes.insert(it, 1, dir);
@@ -1253,13 +1253,13 @@ TQString KStandardDirs::kfsstnd_defaultprefix()
if (!s->defaultprefix.isEmpty())
return s->defaultprefix;
#ifdef Q_WS_WIN
- s->defaultprefix = readEnvPath("KDEDIR");
+ s->defaultprefix = readEnvPath("TDEDIR");
if (s->defaultprefix.isEmpty()) {
s->defaultprefix = TQFile::decodeName("c:\\kde");
//TODO: find other location (the Registry?)
}
#else //UNIX
- s->defaultprefix = KDEDIR;
+ s->defaultprefix = TDEDIR;
#endif
if (s->defaultprefix.isEmpty())
kdWarning() << "KStandardDirs::kfsstnd_defaultprefix(): default KDE prefix not found!" << endl;
@@ -1287,15 +1287,15 @@ void KStandardDirs::addKDEDefaults()
{
TQStringList kdedirList;
- // begin KDEDIRS
- TQString kdedirs = readEnvPath("KDEDIRS");
+ // begin TDEDIRS
+ TQString kdedirs = readEnvPath("TDEDIRS");
if (!kdedirs.isEmpty())
{
tokenize(kdedirList, kdedirs, TQChar(KPATH_SEPARATOR));
}
else
{
- TQString kdedir = readEnvPath("KDEDIR");
+ TQString kdedir = readEnvPath("TDEDIR");
if (!kdedir.isEmpty())
{
kdedir = KShell::tildeExpand(kdedir);
@@ -1303,8 +1303,8 @@ void KStandardDirs::addKDEDefaults()
}
}
-#ifndef Q_OS_WIN //no default KDEDIR on win32 defined
- kdedirList.append(KDEDIR);
+#ifndef Q_OS_WIN //no default TDEDIR on win32 defined
+ kdedirList.append(TDEDIR);
#endif
#ifdef __KDE_EXECPREFIX
@@ -1324,10 +1324,10 @@ void KStandardDirs::addKDEDefaults()
if (getuid() == 0) {
localKdeDir = readEnvPath("KDEROOTHOME");
if (localKdeDir.isEmpty() == true)
- localKdeDir = readEnvPath("KDEHOME");
+ localKdeDir = readEnvPath("TDEHOME");
}
else {
- localKdeDir = readEnvPath("KDEHOME");
+ localKdeDir = readEnvPath("TDEHOME");
}
if (!localKdeDir.isEmpty())
{
@@ -1352,7 +1352,7 @@ void KStandardDirs::addKDEDefaults()
TQString dir = KShell::tildeExpand(*it);
addPrefix(dir);
}
- // end KDEDIRS
+ // end TDEDIRS
// begin XDG_CONFIG_XXX
TQStringList xdgdirList;
@@ -167,7 +167,7 @@ static void priorityAdd(TQStringList &prefixes, const TQString& dir, bool priori
if (priority && !prefixes.isEmpty())
{
- // Add in front but behind $KDEHOME
+ // Add in front but behind $TDEHOME
TQStringList::iterator it = prefixes.begin();
it++;